@@ -64,7 +64,8 @@ class ApiClientWorker:
         autotest_api = AutoTestsApi(api_client=self.__api_client)
 
         autotest = autotest_api.get_all_auto_tests(project_id=self.__config.get_project_id(),
-                                                   external_id=test_result.get_external_id())
+                                                   external_id=test_result.get_external_id(),
+                                                  deleted=False)
 
         if autotest:
             logging.debug(f'Autotest "{test_result.get_autotest_name()}" was found')
@@ -97,7 +98,7 @@ class ApiClientWorker:
                         autotest_global_id,
                         work_item_id_model=WorkItemIdModel(id=work_item_id))
 
-                    logging.debug(f'Autotest "{test_result["autoTestName"]}" was linked with workItem "{work_item_id}"')
+                    logging.debug(f'Autotest "{test_result.get_autotest_name()}" was linked with workItem "{work_item_id}"')
                 except Exception as exc:
                     logging.error(f'Link with workItem "{work_item_id}" status: {exc.status}\n{exc.body}')
 
